<template>
  <el-bus-crud ref="crud" v-bind="tableConfig" />
</template>

<script>
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/banner/page',
        dialogNeedRequest: true,
        persistSelection: true,
        columns: [
          { type: 'selection' },
          { label: 'banner名称', prop: 'name' },
          { label: '图片', formatter: this.formatterImage },
          { label: '应用模块', prop: 'moduleStr' },
          { label: '编辑日期', prop: 'updateTime' },
          { label: '状态', prop: 'statusStr' },
        ],
        searchForm: [
          {
            type: 'row',
            items: [{ label: 'banner名称', id: 'name', type: 'input' }],
          },
        ],
        form: [
          {
            label: 'banner名称：',
            id: 'name',
            type: 'input',
            rules: {
              required: true,
              message: '请输入banner名称',
              trigger: 'blur',
            },
          },
          {
            label: '应用模块：',
            id: 'module',
            type: 'bus-select-dict',
            el: {
              code: 'COMMON_MODULE',
              style: 'width:100%',
            },
            rules: { required: true, message: '请选择应用模块' },
            str: true,
          },
          {
            label: '图片：',
            id: 'url',
            type: 'bus-upload',
            el: {
              listType: 'picture-card',
              limitSize: 2,
              tipText: '大小不超过2M',
            },
            inputFormat: (row) => {
              if ('url' in row) {
                if (row.url) {
                  const url = JSON.parse(row.url)
                  return url.map((item) => ({ url: item }))
                } else {
                  return []
                }
              }
            },
            outputFormat: (val) => {
              return val?.length
                ? JSON.stringify(val.map((item) => item.url))
                : null
            },
            forceDisabled: true,
            rules: { required: true, message: '请上传图片' },
          },
          {
            label: '内容：',
            id: 'content',
            component: 'base-editor',
            richText: true,
            rules: { required: true, message: '请输入内容', trigger: 'blur' },
          },
        ],
        extraButtons: [
          {
            text: (row) => (row.status === 'unpublished' ? '发布' : '下架'),
            atClick: async (row) => {
              const action = row.status === 'unpublished' ? '发布' : '下架'
              try {
                await this.$elBusUtil.confirm(`确定要${action}吗？`)
                const { code } = await this.$elBusHttp.request(
                  'flower/api/banner/page/changeStatus',
                  { params: { id: row.id } }
                )
                if (code === 0) {
                  this.$message.success(`${action}成功`)
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
        headerButtons: [
          {
            text: '批量发布',
            type: 'primary',
            disabled: (selected) =>
              selected.filter((item) => item.status === 'unpublished')
                .length === 0,
            atClick: async (selected) => {
              const selectedNotice = selected.filter(
                (item) => item.status === 'unpublished'
              )
              try {
                await this.$elBusUtil.confirm(
                  `确定要批量发布这${selectedNotice.length}个banner吗？`
                )
                const { code } = await this.$elBusHttp.request(
                  'flower/api/banner/page/publish/batch',
                  {
                    method: 'post',
                    data: {
                      ids: selected.map((item) => item.id),
                    },
                  }
                )
                if (code === 0) {
                  this.$message.success('操作成功')
                  this.$refs.crud.clearSelection()
                }
              } catch (e) {
                return false
              }
            },
          },
          {
            text: '批量删除',
            type: 'danger',
            disabled: (selected) => selected.length === 0,
            atClick: async (selected) => {
              try {
                await this.$elBusUtil.confirm(
                  `确定要批量删除这${selected.length}个banner吗？`
                )
                const { code } = await this.$elBusHttp.request(
                  'flower/api/banner/page/delete/batch',
                  {
                    method: 'post',
                    data: {
                      ids: selected.map((item) => item.id),
                    },
                  }
                )
                if (code === 0) {
                  this.$message.success('操作成功')
                  this.$refs.crud.clearSelection()
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: 'banner管理',
    }
  },
  methods: {
    formatterImage(row) {
      if (row.url) {
        try {
          const url = JSON.parse(row.url)
          if (Array.isArray(url) && url.length > 0) {
            return <el-bus-image src={url[0]} style="width:150px" lazy={true} />
          }
        } catch (e) {
          return null
        }
      }
      return null
    },
  },
}
</script>

<style lang="scss" scoped>
::v-deep {
  .el-upload {
    &-list__item {
      width: 345px;
      height: 128px;
    }
    &.el-upload--picture-card {
      width: 345px;
      height: 128px;
    }
  }
}
</style>
